import { isNodeProcess } from 'is-node-process';
import { rest } from 'msw';

// src/index.ts
var IS_BROWSER = !isNodeProcess();
var api;
var workerPromise;
async function initialize(options) {
  const defaultHandlers = [
    rest.get("/hot-update/*", (req) => req.passthrough()),
    rest.get("/node_modules/*", (req) => req.passthrough())
  ];
  if (IS_BROWSER) {
    const { setupWorker } = await import('msw');
    const worker = setupWorker(...defaultHandlers);
    workerPromise = worker.start(options);
    api = worker;
  } else {
    const { setupServer } = await import('msw/node');
    const server = setupServer(...defaultHandlers);
    workerPromise = Promise.resolve(server.listen(options));
    api = server;
  }
  return api;
}
function getWorker() {
  if (api === void 0) {
    throw new Error(
      `[MSW] Failed to retrieve the worker: no active worker found. Did you forget to call "initialize"?`
    );
  }
  return api;
}
var setupHandlers = (msw) => {
  if (api) {
    api.resetHandlers();
    if (msw) {
      if (Array.isArray(msw) && msw.length > 0) {
        api.use(...msw);
      } else if ("handlers" in msw && msw.handlers) {
        const handlers = Object.values(msw.handlers).filter(Boolean).reduce(
          (handlers2, handlersList) => handlers2.concat(handlersList),
          []
        );
        if (handlers.length > 0) {
          api.use(...handlers);
        }
      }
    }
  }
};
var mswDecorator = (storyFn, context) => {
  const {
    parameters: { msw }
  } = context;
  setupHandlers(msw);
  return storyFn();
};
var mswLoader = async (context) => {
  const {
    parameters: { msw }
  } = context;
  setupHandlers(msw);
  if (workerPromise) {
    await workerPromise;
  }
  return {};
};

export { getWorker, initialize, mswDecorator, mswLoader };
